@@ -1,11 +1,20 @@
 #
-#  Copyright (c) 2019-2021, ETH Zurich. All rights reserved.
+#  Copyright (c) 2019-2022, ETH Zurich. All rights reserved.
 #
 #  Please, refer to the LICENSE file in the root directory.
 #  SPDX-License-Identifier: BSD-3-Clause
 #
+import logging
 import requests
 import time
+import datetime
+
+import firecrest.FirecrestException as fe
+
+from datetime import datetime
+from requests.compat import json
+
+logger = logging.getLogger(__name__)
 
 
 class ClientCredentialsAuth:
@@ -44,6 +53,9 @@ class ClientCredentialsAuth:
             and self._token_expiration_ts
             and time.time() <= (self._token_expiration_ts - self._min_token_validity)
         ):
+            logger.info(
+                f"Reusing token, will renew after {datetime.fromtimestamp(self._token_expiration_ts - self._min_token_validity)}"
+            )
             return self._access_token
 
         headers = {"Content-Type": "application/x-www-form-urlencoded"}
@@ -53,13 +65,20 @@ class ClientCredentialsAuth:
             "client_secret": self._client_secret,
         }
         resp = requests.post(self._token_uri, headers=headers, data=data)
-        resp_json = resp.json()
+        try:
+            resp_json = resp.json()
+        except json.JSONDecodeError:
+            resp_json = ""
+
         if not resp.ok:
-            raise Exception(
-                f"Request to {self._token_uri} failed with "
-                f"status code {resp.status_code}: {resp_json}"
+            logger.critical(
+                f"Could not obtain token: {fe.ClientsCredentialsException([resp])}"
             )
+            raise fe.ClientsCredentialsException([resp])
 
         self._access_token = resp_json["access_token"]
         self._token_expiration_ts = time.time() + resp_json["expires_in"]
+        logger.info(
+            f"Token expires at {datetime.fromtimestamp(self._token_expiration_ts)}"
+        )
         return self._access_token
