@@ -1,5 +1,5 @@
 #
-#  Copyright (c) 2019-2021, ETH Zurich. All rights reserved.
+#  Copyright (c) 2019-2022, ETH Zurich. All rights reserved.
 #
 #  Please, refer to the LICENSE file in the root directory.
 #  SPDX-License-Identifier: BSD-3-Clause
@@ -9,6 +9,7 @@ from firecrest.version import VERSION
 
 
 __version__ = VERSION
+__app_name__ = "firecrest"
 MIN_PYTHON_VERSION = (3, 7, 0)
 
 # Check python version
@@ -27,6 +28,7 @@ from firecrest.BasicClient import (
 )
 from firecrest.Authorization import ClientCredentialsAuth
 from firecrest.FirecrestException import (
+    ClientsCredentialsException,
     FirecrestException,
     UnauthorizedException,
     HeaderException,
